@@ -1,4 +1,4 @@
-/* Copyright © 2007-2015 Jakub Wilk <jwilk@jwilk.net>
+/* Copyright © 2007-2018 Jakub Wilk <jwilk@jwilk.net>
  *
  * This file is part of pdf2djvu.
  *
@@ -25,12 +25,12 @@
 
 #include <CharTypes.h>
 #include <PDFDocEncoding.h>
-#if (POPPLER_VERSION < 2100) || (POPPLER_VERSION >= 2101)
+#if POPPLER_VERSION < 6200
 #include <UTF8.h>
+#else
+#include <UnicodeMapFuncs.h>
 #endif
-#if POPPLER_VERSION >= 2100
 #include <UTF.h>
-#endif
 #include <UnicodeTypeTable.h>
 
 #include <goo/gmem.h>
@@ -46,30 +46,34 @@ void pdf::write_as_utf8(std::ostream &stream, Unicode unicode_char)
     stream.write(buffer, seqlen);
 }
 
-std::string pdf::string_as_utf8(pdf::String *string)
+std::string pdf::string_as_utf8(const pdf::String *string)
 {
     /* See
-     * http://unicode.org/faq/utf_bom.html
+     * https://unicode.org/faq/utf_bom.html
      * for description of both UTF-16 and UTF-8.
      */
-    const static uint32_t replacement_character = 0xfffd;
+    const static uint32_t replacement_character = 0xFFFD;
     const char *cstring = string->getCString();
+#if POPPLER_VERSION < 3500
+    size_t clength = const_cast<pdf::String *>(string)->getLength();
+#else
     size_t clength = string->getLength();
+#endif
     std::ostringstream stream;
-    if (clength >= 2 && (cstring[0] & 0xff) == 0xfe && (cstring[1] & 0xff) == 0xff) {
+    if (clength >= 2 && (cstring[0] & 0xFF) == 0xFE && (cstring[1] & 0xFF) == 0xFF) {
         /* UTF-16-BE Byte Order Mark */
         uint32_t code, code_shift = 0;
         for (size_t i = 2; i < clength; i += 2) {
             if (i + 1 < clength)
-                code = ((cstring[i] & 0xff) << 8) + (cstring[i + 1] & 0xff);
+                code = ((cstring[i] & 0xFF) << 8) + (cstring[i + 1] & 0xFF);
             else {
                 /* lone byte */
                 code = replacement_character;
             }
             if (code_shift) {
-                if (code >= 0xdc00 && code < 0xe000) {
+                if (code >= 0xDC00 && code < 0xE000) {
                     /* trailing surrogate */
-                    code = code_shift + (code & 0x3ff);
+                    code = code_shift + (code & 0x3FF);
                     if (code >= 0x110000)
                         code = replacement_character;
                 } else {
@@ -77,12 +81,12 @@ std::string pdf::string_as_utf8(pdf::String *string)
                     code = replacement_character;
                 }
                 code_shift = 0;
-            } else if (code >= 0xd800 && code < 0xdc00) {
+            } else if (code >= 0xD800 && code < 0xDC00) {
                 /* leading surrogate */
-                code_shift = 0x10000 + ((code & 0x3ff) << 10);
+                code_shift = 0x10000 + ((code & 0x3FF) << 10);
                 continue;
             }
-            if ((code & 0xfffe) == 0xfffe) {
+            if ((code & 0xFFFE) == 0xFFFE) {
                 /* non-character */
                 code = replacement_character;
             }
@@ -95,9 +99,9 @@ std::string pdf::string_as_utf8(pdf::String *string)
                 for (nbytes = 2; nbytes < 4; nbytes++)
                     if (code < (1U << (5 * nbytes + 1)))
                         break;
-                buffer[0] = (0xff00 >> nbytes) & 0xff;
+                buffer[0] = (0xFF00 >> nbytes) & 0xFF;
                 for (size_t i = nbytes - 1; i; i--) {
-                    buffer[i] = 0x80 | (code & 0x3f);
+                    buffer[i] = 0x80 | (code & 0x3F);
                     code >>= 6;
                 }
                 buffer[0] |= code;
@@ -107,7 +111,7 @@ std::string pdf::string_as_utf8(pdf::String *string)
     } else {
         /* PDFDoc encoding */
         for (size_t i = 0; i < clength; i++)
-            write_as_utf8(stream, pdfDocEncoding[cstring[i] & 0xff]);
+            write_as_utf8(stream, pdfDocEncoding[cstring[i] & 0xFF]);
     }
     return stream.str();
 }
@@ -122,13 +126,13 @@ std::string pdf::string_as_utf8(pdf::Object &object)
  */
 
 pdf::FullNFKC::FullNFKC(Unicode *unistr, int length)
-: data(NULL), length_(0)
+: data(nullptr), length_(0)
 {
     assert(length >= 0);
-    this->data = unicodeNormalizeNFKC(unistr, length, &this->length_, NULL);
+    this->data = unicodeNormalizeNFKC(unistr, length, &this->length_, nullptr);
 }
 
-pdf::FullNFKC::~FullNFKC() throw ()
+pdf::FullNFKC::~FullNFKC()
 {
     gfree(this->data);
 }
@@ -137,35 +141,9 @@ pdf::FullNFKC::~FullNFKC() throw ()
  * ======================
  */
 
-#if POPPLER_VERSION < 1900
-const Unicode apf_min = 0xFB00;
-const Unicode apf_max = 0xFB4F;
-#endif
-
 pdf::MinimalNFKC::MinimalNFKC(Unicode *unistr, int length)
 {
-    /* Poppler 0.19.0 (and later versions) performs NFKC normalization of
-     * characters from the Alphabetic Presentation Forms block
-     * (U+FB00–U+FB4F):
-     * https://bugs.freedesktop.org/show_bug.cgi?id=7002
-     * For older versions, we do the same normalization ourselves.
-     */
-#if POPPLER_VERSION < 1900
-    std::basic_ostringstream<Unicode> stream;
-    for (int i = 0; i < length; i++) {
-        if (unistr[i] >= apf_min && unistr[i] <= apf_max) {
-            int clen;
-            Unicode *cstr = unicodeNormalizeNFKC(unistr + i, 1, &clen, NULL);
-            stream.write(cstr, clen);
-            gfree(cstr);
-        } else {
-            stream.write(unistr + i, 1);
-        }
-    }
-    this->string += stream.str();
-#else
     this->string.append(unistr, length);
-#endif
 }
 
 int pdf::MinimalNFKC::length() const
