@@ -1,4 +1,4 @@
-/* Copyright © 2007-2017 Jakub Wilk <jwilk@jwilk.net>
+/* Copyright © 2007-2018 Jakub Wilk <jwilk@jwilk.net>
  * Copyright © 2009 Mateusz Turcza
  *
  * This file is part of pdf2djvu.
@@ -73,11 +73,14 @@ public:
 static int get_page_for_goto_link(pdf::link::GoTo *goto_link, pdf::Catalog *catalog)
 {
   std::unique_ptr<pdf::link::Destination> dest;
-  dest.reset(goto_link->getDest());
-  if (dest.get() == nullptr)
+#if POPPLER_VERSION >= 6400
+  const
+#endif
+  pdf::link::Destination *orig_dest = goto_link->getDest();
+  if (orig_dest == nullptr)
     dest.reset(catalog->findDest(goto_link->getNamedDest()));
   else
-    dest.reset(dest.release()->copy());
+    dest.reset(orig_dest->copy());
   if (dest.get() != nullptr)
   {
     int page;
